@@ -37,12 +37,12 @@ BIGIMG1=`awk -F"," '$1=='"$IMGCHOICE"' {print $4}' $IMGLIST`
 MD51=`awk -F"," '$1=='"$IMGCHOICE"' {print $7}' $IMGLIST`
 IMGCMPRSS=`awk -F"," '$1=='"$IMGCHOICE"' {print $5}' $IMGLIST`
 
-echo $DLURL
-echo $PKGNAME1
-echo $BIGTAR1
-echo $BIGIMG1
-echo $MD51
-echo $IMGCMPRSS
+#echo $DLURL
+#echo $PKGNAME1
+#echo $BIGTAR1
+#echo $BIGIMG1
+#echo $MD51
+#echo $IMGCMPRSS
 
 ## Make sure the chroot is closed, to avoid spurious mounts
 
@@ -72,7 +72,7 @@ esac
 
 echo "Downloading and extracting $BIGIMG1 to $SDCARD..."
 
-exit 0
+# exit 0
 
 ## HERE ARE THE REST OF THE VARIABLES:
 
